package jalview.gui;

import jalview.datamodel.PDBEntry;
import jalview.datamodel.SequenceI;
import jalview.ext.rbvi.chimera.ChimeraXCommands;
import jalview.gui.StructureViewer.ViewerType;
import jalview.io.DataSourceType;
import jalview.structure.StructureCommand;
import jalview.structure.StructureSelectionManager;

import java.util.List;

import ext.edu.ucsf.rbvi.strucviz2.ChimeraModel;
import ext.edu.ucsf.rbvi.strucviz2.StructureManager;
import ext.edu.ucsf.rbvi.strucviz2.StructureManager.ModelType;

public class JalviewChimeraXBindingModel extends JalviewChimeraBindingModel
{

  public JalviewChimeraXBindingModel(ChimeraViewFrame chimeraViewFrame,
          StructureSelectionManager ssm, PDBEntry[] pdbentry,
          SequenceI[][] sequenceIs, DataSourceType protocol)
  {
    super(chimeraViewFrame, ssm, pdbentry, sequenceIs, protocol);
    setStructureCommands(new ChimeraXCommands());
  }

  @Override
  protected List<String> getChimeraPaths()
  {
    return StructureManager.getChimeraPaths(true);
  }

  @Override
  protected void addChimeraModel(PDBEntry pe,
          List<ChimeraModel> modelsToMap)
  {
    /*
     * ChimeraX hack: force chimera model name to pdbId here
     */
    int modelNumber = chimeraMaps.size() + 1;
    String command = "setattr #" + modelNumber + " models name "
            + pe.getId();
    executeCommand(new StructureCommand(command), false);
    modelsToMap.add(new ChimeraModel(pe.getId(), ModelType.PDB_MODEL,
            modelNumber, 0));
  }

  /**
   * {@inheritDoc}
   * 
   * @return
   */
  @Override
  protected String getCommandFileExtension()
  {
    return ".cxc";
  }

  /**
   * Returns the file extension to use for a saved viewer session file
   * 
   * @return
   */
  @Override
  public String getSessionFileExtension()
  {
    return ".cxs";
  }

  @Override
  public String getHelpURL()
  {
    return "http://www.rbvi.ucsf.edu/chimerax/docs/user/index.html";
  }

  @Override
  protected ViewerType getViewerType()
  {
    return ViewerType.CHIMERAX;
  }

  @Override
  protected String getModelId(int pdbfnum, String file)
  {
    return String.valueOf(pdbfnum + 1);
  }

}
